"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.backup.v1.backup_pb2
import yandex.cloud.backup.v1.resource_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ListArchivesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """List of archives in specified folder."""
    compute_instance_id: builtins.str
    """List of archives of the specified Compute Cloud instance."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        compute_instance_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["compute_instance_id", b"compute_instance_id", "folder_id", b"folder_id", "id", b"id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["compute_instance_id", b"compute_instance_id", "folder_id", b"folder_id", "id", b"id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["id", b"id"]) -> typing.Literal["folder_id", "compute_instance_id"] | None: ...

global___ListArchivesRequest = ListArchivesRequest

@typing.final
class ListArchivesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARCHIVES_FIELD_NUMBER: builtins.int
    @property
    def archives(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.backup.v1.backup_pb2.Archive]: ...
    def __init__(
        self,
        *,
        archives: collections.abc.Iterable[yandex.cloud.backup.v1.backup_pb2.Archive] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["archives", b"archives"]) -> None: ...

global___ListArchivesResponse = ListArchivesResponse

@typing.final
class ListBackupsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ArchiveParameters(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ARCHIVE_ID_FIELD_NUMBER: builtins.int
        FOLDER_ID_FIELD_NUMBER: builtins.int
        archive_id: builtins.str
        """Archive ID."""
        folder_id: builtins.str
        """Folder ID."""
        def __init__(
            self,
            *,
            archive_id: builtins.str = ...,
            folder_id: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["archive_id", b"archive_id", "folder_id", b"folder_id"]) -> None: ...

    @typing.final
    class InstancePolicy(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
        POLICY_ID_FIELD_NUMBER: builtins.int
        compute_instance_id: builtins.str
        """Compute Cloud instance ID."""
        policy_id: builtins.str
        """Policy ID."""
        def __init__(
            self,
            *,
            compute_instance_id: builtins.str = ...,
            policy_id: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["compute_instance_id", b"compute_instance_id", "policy_id", b"policy_id"]) -> None: ...

    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    ARCHIVE_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    INSTANCE_POLICY_FIELD_NUMBER: builtins.int
    RESOURCE_ID_FIELD_NUMBER: builtins.int
    POLICY_ID_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    compute_instance_id: builtins.str
    """List backups that belongs to specific Compute Cloud instance."""
    folder_id: builtins.str
    """List backups that belongs to specific folder."""
    resource_id: builtins.str
    """List backups by specific resource ID."""
    policy_id: builtins.str
    """List backups by specific policy ID."""
    order_by: builtins.str
    """By which column the listing should be ordered and in which direction,
    format is "createdAt desc". "createdAt desc" if omitted.
    """
    filter: builtins.str
    """Filter list by various parameters.
    Supported parameters are:
    * created_at

    Supported logic operators:
    * AND
    """
    type: yandex.cloud.backup.v1.resource_pb2.ResourceType.ValueType
    """Type of resource. Could be compute VM or baremetal server."""
    @property
    def archive(self) -> global___ListBackupsRequest.ArchiveParameters:
        """List backups that belongs to specific archive of specific folder."""

    @property
    def instance_policy(self) -> global___ListBackupsRequest.InstancePolicy:
        """List backups that belongs to specific instance and policy at the same time."""

    def __init__(
        self,
        *,
        compute_instance_id: builtins.str = ...,
        archive: global___ListBackupsRequest.ArchiveParameters | None = ...,
        folder_id: builtins.str = ...,
        instance_policy: global___ListBackupsRequest.InstancePolicy | None = ...,
        resource_id: builtins.str = ...,
        policy_id: builtins.str = ...,
        order_by: builtins.str = ...,
        filter: builtins.str = ...,
        type: yandex.cloud.backup.v1.resource_pb2.ResourceType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["archive", b"archive", "compute_instance_id", b"compute_instance_id", "folder_id", b"folder_id", "id", b"id", "instance_policy", b"instance_policy", "policy_id", b"policy_id", "resource_id", b"resource_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["archive", b"archive", "compute_instance_id", b"compute_instance_id", "filter", b"filter", "folder_id", b"folder_id", "id", b"id", "instance_policy", b"instance_policy", "order_by", b"order_by", "policy_id", b"policy_id", "resource_id", b"resource_id", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["id", b"id"]) -> typing.Literal["compute_instance_id", "archive", "folder_id", "instance_policy", "resource_id", "policy_id"] | None: ...

global___ListBackupsRequest = ListBackupsRequest

@typing.final
class ListBackupsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKUPS_FIELD_NUMBER: builtins.int
    @property
    def backups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.backup.v1.backup_pb2.Backup]: ...
    def __init__(
        self,
        *,
        backups: collections.abc.Iterable[yandex.cloud.backup.v1.backup_pb2.Backup] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backups", b"backups"]) -> None: ...

global___ListBackupsResponse = ListBackupsResponse

@typing.final
class ListFilesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    BACKUP_ID_FIELD_NUMBER: builtins.int
    SOURCE_ID_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """Folder ID."""
    backup_id: builtins.str
    """Backup ID."""
    source_id: builtins.str
    """Empty source will list disks of the backup."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        backup_id: builtins.str = ...,
        source_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backup_id", b"backup_id", "folder_id", b"folder_id", "source_id", b"source_id"]) -> None: ...

global___ListFilesRequest = ListFilesRequest

@typing.final
class ListFilesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILES_FIELD_NUMBER: builtins.int
    @property
    def files(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.backup.v1.backup_pb2.BackupFile]: ...
    def __init__(
        self,
        *,
        files: collections.abc.Iterable[yandex.cloud.backup.v1.backup_pb2.BackupFile] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["files", b"files"]) -> None: ...

global___ListFilesResponse = ListFilesResponse

@typing.final
class GetBackupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKUP_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    backup_id: builtins.str
    """Backup ID."""
    folder_id: builtins.str
    """Folder ID."""
    def __init__(
        self,
        *,
        backup_id: builtins.str = ...,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backup_id", b"backup_id", "folder_id", b"folder_id"]) -> None: ...

global___GetBackupRequest = GetBackupRequest

@typing.final
class StartRecoveryRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    BACKUP_ID_FIELD_NUMBER: builtins.int
    compute_instance_id: builtins.str
    """Destination Compute Cloud instance ID to which backup should be applied."""
    backup_id: builtins.str
    """Backup ID that will be applied to destination Compute Cloud instance."""
    def __init__(
        self,
        *,
        compute_instance_id: builtins.str = ...,
        backup_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backup_id", b"backup_id", "compute_instance_id", b"compute_instance_id"]) -> None: ...

global___StartRecoveryRequest = StartRecoveryRequest

@typing.final
class StartRecoveryMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROGRESS_PERCENTAGE_FIELD_NUMBER: builtins.int
    SRC_BACKUP_ID_FIELD_NUMBER: builtins.int
    DST_COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    progress_percentage: builtins.float
    """Progress of the backup process."""
    src_backup_id: builtins.str
    """Source Backup ID that will be applied."""
    dst_compute_instance_id: builtins.str
    """Destination Compute Cloud instance ID to which backup will be applied."""
    def __init__(
        self,
        *,
        progress_percentage: builtins.float = ...,
        src_backup_id: builtins.str = ...,
        dst_compute_instance_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dst_compute_instance_id", b"dst_compute_instance_id", "progress_percentage", b"progress_percentage", "src_backup_id", b"src_backup_id"]) -> None: ...

global___StartRecoveryMetadata = StartRecoveryMetadata

@typing.final
class TargetPathOriginal(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___TargetPathOriginal = TargetPathOriginal

@typing.final
class TargetPathCustom(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    path: builtins.str
    """Custom folder for file recovery."""
    def __init__(
        self,
        *,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["path", b"path"]) -> None: ...

global___TargetPathCustom = TargetPathCustom

@typing.final
class FilesRecoveryOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Overwrite:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _OverwriteEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[FilesRecoveryOptions._Overwrite.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        OVERWRITE_UNSPECIFIED: FilesRecoveryOptions._Overwrite.ValueType  # 0
        """Unspecified value treated as Overwrite all"""
        OVERWRITE_ALL: FilesRecoveryOptions._Overwrite.ValueType  # 1
        """All overwrites all existing files by recovered ones."""
        OVERWRITE_OLDER: FilesRecoveryOptions._Overwrite.ValueType  # 2
        """Older overwrites older files only."""
        OVERWRITE_NONE: FilesRecoveryOptions._Overwrite.ValueType  # 3
        """None does not overwrites files at all."""

    class Overwrite(_Overwrite, metaclass=_OverwriteEnumTypeWrapper): ...
    OVERWRITE_UNSPECIFIED: FilesRecoveryOptions.Overwrite.ValueType  # 0
    """Unspecified value treated as Overwrite all"""
    OVERWRITE_ALL: FilesRecoveryOptions.Overwrite.ValueType  # 1
    """All overwrites all existing files by recovered ones."""
    OVERWRITE_OLDER: FilesRecoveryOptions.Overwrite.ValueType  # 2
    """Older overwrites older files only."""
    OVERWRITE_NONE: FilesRecoveryOptions.Overwrite.ValueType  # 3
    """None does not overwrites files at all."""

    OVERWRITE_FIELD_NUMBER: builtins.int
    REBOOT_IF_NEEDED_FIELD_NUMBER: builtins.int
    ORIGINAL_FIELD_NUMBER: builtins.int
    CUSTOM_FIELD_NUMBER: builtins.int
    overwrite: global___FilesRecoveryOptions.Overwrite.ValueType
    """Overwrite options declares the behavior for files that already exists on the file system."""
    reboot_if_needed: builtins.bool
    """specifies whether the recovery plan is able to reboot host if needed."""
    @property
    def original(self) -> global___TargetPathOriginal:
        """Keep original paths of files."""

    @property
    def custom(self) -> global___TargetPathCustom:
        """Set custom folder for file recovery."""

    def __init__(
        self,
        *,
        overwrite: global___FilesRecoveryOptions.Overwrite.ValueType = ...,
        reboot_if_needed: builtins.bool = ...,
        original: global___TargetPathOriginal | None = ...,
        custom: global___TargetPathCustom | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["custom", b"custom", "original", b"original", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["custom", b"custom", "original", b"original", "overwrite", b"overwrite", "reboot_if_needed", b"reboot_if_needed", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["type", b"type"]) -> typing.Literal["original", "custom"] | None: ...

global___FilesRecoveryOptions = FilesRecoveryOptions

@typing.final
class StartFilesRecoveryRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    BACKUP_ID_FIELD_NUMBER: builtins.int
    OPTS_FIELD_NUMBER: builtins.int
    SOURCE_IDS_FIELD_NUMBER: builtins.int
    compute_instance_id: builtins.str
    """Destination instance ID."""
    backup_id: builtins.str
    """Backup ID."""
    @property
    def opts(self) -> global___FilesRecoveryOptions: ...
    @property
    def source_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        compute_instance_id: builtins.str = ...,
        backup_id: builtins.str = ...,
        opts: global___FilesRecoveryOptions | None = ...,
        source_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["opts", b"opts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["backup_id", b"backup_id", "compute_instance_id", b"compute_instance_id", "opts", b"opts", "source_ids", b"source_ids"]) -> None: ...

global___StartFilesRecoveryRequest = StartFilesRecoveryRequest

@typing.final
class StartFilesRecoveryMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROGRESS_PERCENTAGE_FIELD_NUMBER: builtins.int
    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    BACKUP_ID_FIELD_NUMBER: builtins.int
    SOURCE_IDS_FIELD_NUMBER: builtins.int
    progress_percentage: builtins.float
    compute_instance_id: builtins.str
    """Destination instance ID."""
    backup_id: builtins.str
    """Backup ID."""
    @property
    def source_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        progress_percentage: builtins.float = ...,
        compute_instance_id: builtins.str = ...,
        backup_id: builtins.str = ...,
        source_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backup_id", b"backup_id", "compute_instance_id", b"compute_instance_id", "progress_percentage", b"progress_percentage", "source_ids", b"source_ids"]) -> None: ...

global___StartFilesRecoveryMetadata = StartFilesRecoveryMetadata

@typing.final
class DeleteBackupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    BACKUP_ID_FIELD_NUMBER: builtins.int
    compute_instance_id: builtins.str
    """Compute Cloud instance ID of the Backup."""
    backup_id: builtins.str
    """Backup ID that should be deleted."""
    def __init__(
        self,
        *,
        compute_instance_id: builtins.str = ...,
        backup_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backup_id", b"backup_id", "compute_instance_id", b"compute_instance_id"]) -> None: ...

global___DeleteBackupRequest = DeleteBackupRequest

@typing.final
class DeleteBackupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    BACKUP_ID_FIELD_NUMBER: builtins.int
    compute_instance_id: builtins.str
    """Compute Cloud instance ID of the Backup."""
    backup_id: builtins.str
    """Backup ID that should be deleted."""
    def __init__(
        self,
        *,
        compute_instance_id: builtins.str = ...,
        backup_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backup_id", b"backup_id", "compute_instance_id", b"compute_instance_id"]) -> None: ...

global___DeleteBackupMetadata = DeleteBackupMetadata



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/logging/v1/log_group_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.logging.v1 import log_group_pb2 as yandex_dot_cloud_dot_logging_dot_v1_dot_log__group__pb2
from yandex.cloud.logging.v1 import log_resource_pb2 as yandex_dot_cloud_dot_logging_dot_v1_dot_log__resource__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/yandex/cloud/logging/v1/log_group_service.proto\x12\x17yandex.cloud.logging.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/access/access.proto\x1a\'yandex/cloud/logging/v1/log_group.proto\x1a*yandex/cloud/logging/v1/log_resource.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"8\n\x12GetLogGroupRequest\x12\"\n\x0clog_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\"=\n\x17GetLogGroupStatsRequest\x12\"\n\x0clog_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\"\x85\x01\n\x14ListLogGroupsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"c\n\x15ListLogGroupsResponse\x12\x31\n\x06groups\x18\x01 \x03(\x0b\x32!.yandex.cloud.logging.v1.LogGroup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x9c\x03\n\x15\x43reateLogGroupRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12\x34\n\x04name\x18\x02 \x01(\tB&\xf2\xc7\x31\"([a-z]([-a-z0-9]{1,61}[a-z0-9])?)?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x87\x01\n\x06labels\x18\x04 \x03(\x0b\x32:.yandex.cloud.logging.v1.CreateLogGroupRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x33\n\x10retention_period\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1e\n\x0b\x64\x61ta_stream\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=512\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\".\n\x16\x43reateLogGroupMetadata\x12\x14\n\x0clog_group_id\x18\x01 \x01(\t\"\xd0\x03\n\x15UpdateLogGroupRequest\x12\"\n\x0clog_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x34\n\x04name\x18\x03 \x01(\tB&\xf2\xc7\x31\"([a-z]([-a-z0-9]{1,61}[a-z0-9])?)?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x87\x01\n\x06labels\x18\x05 \x03(\x0b\x32:.yandex.cloud.logging.v1.UpdateLogGroupRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x33\n\x10retention_period\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1e\n\x0b\x64\x61ta_stream\x18\x07 \x01(\tB\t\x8a\xc8\x31\x05<=512\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\".\n\x16UpdateLogGroupMetadata\x12\x14\n\x0clog_group_id\x18\x01 \x01(\t\";\n\x15\x44\x65leteLogGroupRequest\x12\"\n\x0clog_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\".\n\x16\x44\x65leteLogGroupMetadata\x12\x14\n\x0clog_group_id\x18\x01 \x01(\t\"S\n\x14ListResourcesRequest\x12\"\n\x0clog_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12\x17\n\x04type\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=256\"U\n\x15ListResourcesResponse\x12<\n\tresources\x18\x01 \x03(\x0b\x32).yandex.cloud.logging.v1.LogGroupResource\"\x95\x01\n\x15ListOperationsRequest\x12\"\n\x0clog_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"h\n\x16ListOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"P\n\x18GetLogGroupStatsResponse\x12\x14\n\x0clog_group_id\x18\x01 \x01(\t\x12\r\n\x05\x62ytes\x18\x02 \x01(\x03\x12\x0f\n\x07records\x18\x03 \x01(\x03\x32\xc8\x0f\n\x0fLogGroupService\x12\x83\x01\n\x03Get\x12+.yandex.cloud.logging.v1.GetLogGroupRequest\x1a!.yandex.cloud.logging.v1.LogGroup\",\x82\xd3\xe4\x93\x02&\x12$/logging/v1/logGroups/{log_group_id}\x12\xa0\x01\n\x05Stats\x12\x30.yandex.cloud.logging.v1.GetLogGroupStatsRequest\x1a\x31.yandex.cloud.logging.v1.GetLogGroupStatsResponse\"2\x82\xd3\xe4\x93\x02,\x12*/logging/v1/logGroups/{log_group_id}/stats\x12\x84\x01\n\x04List\x12-.yandex.cloud.logging.v1.ListLogGroupsRequest\x1a..yandex.cloud.logging.v1.ListLogGroupsResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/logging/v1/logGroups\x12\xa3\x01\n\x06\x43reate\x12..yandex.cloud.logging.v1.CreateLogGroupRequest\x1a!.yandex.cloud.operation.Operation\"F\xb2\xd2*\"\n\x16\x43reateLogGroupMetadata\x12\x08LogGroup\x82\xd3\xe4\x93\x02\x1a\"\x15/logging/v1/logGroups:\x01*\x12\xb2\x01\n\x06Update\x12..yandex.cloud.logging.v1.UpdateLogGroupRequest\x1a!.yandex.cloud.operation.Operation\"U\xb2\xd2*\"\n\x16UpdateLogGroupMetadata\x12\x08LogGroup\x82\xd3\xe4\x93\x02)2$/logging/v1/logGroups/{log_group_id}:\x01*\x12\xbc\x01\n\x06\x44\x65lete\x12..yandex.cloud.logging.v1.DeleteLogGroupRequest\x1a!.yandex.cloud.operation.Operation\"_\xb2\xd2*/\n\x16\x44\x65leteLogGroupMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02&*$/logging/v1/logGroups/{log_group_id}\x12\xaa\x01\n\rListResources\x12-.yandex.cloud.logging.v1.ListResourcesRequest\x1a..yandex.cloud.logging.v1.ListResourcesResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/logging/v1/logGroups/{log_group_id}:listResources\x12\xaa\x01\n\x0eListOperations\x12..yandex.cloud.logging.v1.ListOperationsRequest\x1a/.yandex.cloud.logging.v1.ListOperationsResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//logging/v1/logGroups/{log_group_id}/operations\x12\xb5\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/logging/v1/logGroups/{resource_id}:listAccessBindings\x12\xe4\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"}\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02:\"5/logging/v1/logGroups/{resource_id}:setAccessBindings:\x01*\x12\xf1\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x83\x01\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02=28/logging/v1/logGroups/{resource_id}:updateAccessBindings:\x01*Bb\n\x1byandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;loggingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.logging.v1.log_group_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;logging'
  _GETLOGGROUPREQUEST.fields_by_name['log_group_id']._options = None
  _GETLOGGROUPREQUEST.fields_by_name['log_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _GETLOGGROUPSTATSREQUEST.fields_by_name['log_group_id']._options = None
  _GETLOGGROUPSTATSREQUEST.fields_by_name['log_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _LISTLOGGROUPSREQUEST.fields_by_name['folder_id']._options = None
  _LISTLOGGROUPSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _LISTLOGGROUPSREQUEST.fields_by_name['page_token']._options = None
  _LISTLOGGROUPSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTLOGGROUPSREQUEST.fields_by_name['filter']._options = None
  _LISTLOGGROUPSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _CREATELOGGROUPREQUEST_LABELSENTRY._options = None
  _CREATELOGGROUPREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATELOGGROUPREQUEST.fields_by_name['folder_id']._options = None
  _CREATELOGGROUPREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _CREATELOGGROUPREQUEST.fields_by_name['name']._options = None
  _CREATELOGGROUPREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\"([a-z]([-a-z0-9]{1,61}[a-z0-9])?)?'
  _CREATELOGGROUPREQUEST.fields_by_name['description']._options = None
  _CREATELOGGROUPREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATELOGGROUPREQUEST.fields_by_name['labels']._options = None
  _CREATELOGGROUPREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _CREATELOGGROUPREQUEST.fields_by_name['data_stream']._options = None
  _CREATELOGGROUPREQUEST.fields_by_name['data_stream']._serialized_options = b'\212\3101\005<=512'
  _UPDATELOGGROUPREQUEST_LABELSENTRY._options = None
  _UPDATELOGGROUPREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATELOGGROUPREQUEST.fields_by_name['log_group_id']._options = None
  _UPDATELOGGROUPREQUEST.fields_by_name['log_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _UPDATELOGGROUPREQUEST.fields_by_name['name']._options = None
  _UPDATELOGGROUPREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\"([a-z]([-a-z0-9]{1,61}[a-z0-9])?)?'
  _UPDATELOGGROUPREQUEST.fields_by_name['description']._options = None
  _UPDATELOGGROUPREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATELOGGROUPREQUEST.fields_by_name['labels']._options = None
  _UPDATELOGGROUPREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _UPDATELOGGROUPREQUEST.fields_by_name['data_stream']._options = None
  _UPDATELOGGROUPREQUEST.fields_by_name['data_stream']._serialized_options = b'\212\3101\005<=512'
  _DELETELOGGROUPREQUEST.fields_by_name['log_group_id']._options = None
  _DELETELOGGROUPREQUEST.fields_by_name['log_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _LISTRESOURCESREQUEST.fields_by_name['log_group_id']._options = None
  _LISTRESOURCESREQUEST.fields_by_name['log_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _LISTRESOURCESREQUEST.fields_by_name['type']._options = None
  _LISTRESOURCESREQUEST.fields_by_name['type']._serialized_options = b'\212\3101\005<=256'
  _LISTOPERATIONSREQUEST.fields_by_name['log_group_id']._options = None
  _LISTOPERATIONSREQUEST.fields_by_name['log_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _LISTOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTOPERATIONSREQUEST.fields_by_name['filter']._options = None
  _LISTOPERATIONSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _LOGGROUPSERVICE.methods_by_name['Get']._options = None
  _LOGGROUPSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002&\022$/logging/v1/logGroups/{log_group_id}'
  _LOGGROUPSERVICE.methods_by_name['Stats']._options = None
  _LOGGROUPSERVICE.methods_by_name['Stats']._serialized_options = b'\202\323\344\223\002,\022*/logging/v1/logGroups/{log_group_id}/stats'
  _LOGGROUPSERVICE.methods_by_name['List']._options = None
  _LOGGROUPSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\027\022\025/logging/v1/logGroups'
  _LOGGROUPSERVICE.methods_by_name['Create']._options = None
  _LOGGROUPSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\"\n\026CreateLogGroupMetadata\022\010LogGroup\202\323\344\223\002\032\"\025/logging/v1/logGroups:\001*'
  _LOGGROUPSERVICE.methods_by_name['Update']._options = None
  _LOGGROUPSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\"\n\026UpdateLogGroupMetadata\022\010LogGroup\202\323\344\223\002)2$/logging/v1/logGroups/{log_group_id}:\001*'
  _LOGGROUPSERVICE.methods_by_name['Delete']._options = None
  _LOGGROUPSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*/\n\026DeleteLogGroupMetadata\022\025google.protobuf.Empty\202\323\344\223\002&*$/logging/v1/logGroups/{log_group_id}'
  _LOGGROUPSERVICE.methods_by_name['ListResources']._options = None
  _LOGGROUPSERVICE.methods_by_name['ListResources']._serialized_options = b'\202\323\344\223\0024\0222/logging/v1/logGroups/{log_group_id}:listResources'
  _LOGGROUPSERVICE.methods_by_name['ListOperations']._options = None
  _LOGGROUPSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0021\022//logging/v1/logGroups/{log_group_id}/operations'
  _LOGGROUPSERVICE.methods_by_name['ListAccessBindings']._options = None
  _LOGGROUPSERVICE.methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\0028\0226/logging/v1/logGroups/{resource_id}:listAccessBindings'
  _LOGGROUPSERVICE.methods_by_name['SetAccessBindings']._options = None
  _LOGGROUPSERVICE.methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002:\"5/logging/v1/logGroups/{resource_id}:setAccessBindings:\001*'
  _LOGGROUPSERVICE.methods_by_name['UpdateAccessBindings']._options = None
  _LOGGROUPSERVICE.methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002=28/logging/v1/logGroups/{resource_id}:updateAccessBindings:\001*'
  _globals['_GETLOGGROUPREQUEST']._serialized_start=396
  _globals['_GETLOGGROUPREQUEST']._serialized_end=452
  _globals['_GETLOGGROUPSTATSREQUEST']._serialized_start=454
  _globals['_GETLOGGROUPSTATSREQUEST']._serialized_end=515
  _globals['_LISTLOGGROUPSREQUEST']._serialized_start=518
  _globals['_LISTLOGGROUPSREQUEST']._serialized_end=651
  _globals['_LISTLOGGROUPSRESPONSE']._serialized_start=653
  _globals['_LISTLOGGROUPSRESPONSE']._serialized_end=752
  _globals['_CREATELOGGROUPREQUEST']._serialized_start=755
  _globals['_CREATELOGGROUPREQUEST']._serialized_end=1167
  _globals['_CREATELOGGROUPREQUEST_LABELSENTRY']._serialized_start=1122
  _globals['_CREATELOGGROUPREQUEST_LABELSENTRY']._serialized_end=1167
  _globals['_CREATELOGGROUPMETADATA']._serialized_start=1169
  _globals['_CREATELOGGROUPMETADATA']._serialized_end=1215
  _globals['_UPDATELOGGROUPREQUEST']._serialized_start=1218
  _globals['_UPDATELOGGROUPREQUEST']._serialized_end=1682
  _globals['_UPDATELOGGROUPREQUEST_LABELSENTRY']._serialized_start=1122
  _globals['_UPDATELOGGROUPREQUEST_LABELSENTRY']._serialized_end=1167
  _globals['_UPDATELOGGROUPMETADATA']._serialized_start=1684
  _globals['_UPDATELOGGROUPMETADATA']._serialized_end=1730
  _globals['_DELETELOGGROUPREQUEST']._serialized_start=1732
  _globals['_DELETELOGGROUPREQUEST']._serialized_end=1791
  _globals['_DELETELOGGROUPMETADATA']._serialized_start=1793
  _globals['_DELETELOGGROUPMETADATA']._serialized_end=1839
  _globals['_LISTRESOURCESREQUEST']._serialized_start=1841
  _globals['_LISTRESOURCESREQUEST']._serialized_end=1924
  _globals['_LISTRESOURCESRESPONSE']._serialized_start=1926
  _globals['_LISTRESOURCESRESPONSE']._serialized_end=2011
  _globals['_LISTOPERATIONSREQUEST']._serialized_start=2014
  _globals['_LISTOPERATIONSREQUEST']._serialized_end=2163
  _globals['_LISTOPERATIONSRESPONSE']._serialized_start=2165
  _globals['_LISTOPERATIONSRESPONSE']._serialized_end=2269
  _globals['_GETLOGGROUPSTATSRESPONSE']._serialized_start=2271
  _globals['_GETLOGGROUPSTATSRESPONSE']._serialized_end=2351
  _globals['_LOGGROUPSERVICE']._serialized_start=2354
  _globals['_LOGGROUPSERVICE']._serialized_end=4346
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class AsymmetricDecryptRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    CIPHERTEXT_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the asymmetric KMS key to use for decryption."""
    ciphertext: builtins.bytes
    """Ciphertext to be decrypted.
    Should be encoded with base64.
    """
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        ciphertext: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["ciphertext", b"ciphertext", "key_id", b"key_id"]) -> None: ...

global___AsymmetricDecryptRequest = AsymmetricDecryptRequest

@typing.final
class AsymmetricDecryptResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    PLAINTEXT_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the asymmetric KMS key that was used for decryption."""
    plaintext: builtins.bytes
    """Decrypted plaintext."""
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        plaintext: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id", "plaintext", b"plaintext"]) -> None: ...

global___AsymmetricDecryptResponse = AsymmetricDecryptResponse

@typing.final
class AsymmetricGetPublicKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the asymmetric KMS key to be used for public key retrieval."""
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id"]) -> None: ...

global___AsymmetricGetPublicKeyRequest = AsymmetricGetPublicKeyRequest

@typing.final
class AsymmetricGetPublicKeyResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_ID_FIELD_NUMBER: builtins.int
    PUBLIC_KEY_FIELD_NUMBER: builtins.int
    key_id: builtins.str
    """ID of the asymmetric KMS key to get public key of."""
    public_key: builtins.str
    """Public key value.
    The value is a PEM-encoded X.509 public key, also known as SubjectPublicKeyInfo (SPKI),
    as defined in RFC 5280.
    """
    def __init__(
        self,
        *,
        key_id: builtins.str = ...,
        public_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key_id", b"key_id", "public_key", b"public_key"]) -> None: ...

global___AsymmetricGetPublicKeyResponse = AsymmetricGetPublicKeyResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _BindingType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _BindingTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_BindingType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    BINDING_TYPE_UNSPECIFIED: _BindingType.ValueType  # 0
    POST: _BindingType.ValueType  # 1
    """HTTP POST binding."""
    REDIRECT: _BindingType.ValueType  # 2
    """HTTP redirect binding."""
    ARTIFACT: _BindingType.ValueType  # 3
    """HTTP artifact binding."""

class BindingType(_BindingType, metaclass=_BindingTypeEnumTypeWrapper): ...

BINDING_TYPE_UNSPECIFIED: BindingType.ValueType  # 0
POST: BindingType.ValueType  # 1
"""HTTP POST binding."""
REDIRECT: BindingType.ValueType  # 2
"""HTTP redirect binding."""
ARTIFACT: BindingType.ValueType  # 3
"""HTTP artifact binding."""
global___BindingType = BindingType

@typing.final
class Federation(google.protobuf.message.Message):
    """A federation.
    For more information, see [SAML-compatible identity federations](/docs/iam/concepts/federations).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    COOKIE_MAX_AGE_FIELD_NUMBER: builtins.int
    AUTO_CREATE_ACCOUNT_ON_LOGIN_FIELD_NUMBER: builtins.int
    ISSUER_FIELD_NUMBER: builtins.int
    SSO_BINDING_FIELD_NUMBER: builtins.int
    SSO_URL_FIELD_NUMBER: builtins.int
    SECURITY_SETTINGS_FIELD_NUMBER: builtins.int
    CASE_INSENSITIVE_NAME_IDS_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the federation."""
    organization_id: builtins.str
    """ID of the organization that the federation belongs to."""
    name: builtins.str
    """Name of the federation."""
    description: builtins.str
    """Description of the federation."""
    auto_create_account_on_login: builtins.bool
    """Add new users automatically on successful authentication.
    The user becomes member of the organization automatically,
    but you need to grant other roles to them.

    If the value is `false`, users who aren't added to the organization
    can't log in, even if they have authenticated on your server.
    """
    issuer: builtins.str
    """ID of the IdP server to be used for authentication.
    The IdP server also responds to IAM with this ID after the user authenticates.
    """
    sso_binding: global___BindingType.ValueType
    """Single sign-on endpoint binding type. Most Identity Providers support the `POST` binding type.

    SAML Binding is a mapping of a SAML protocol message onto standard messaging
    formats and/or communications protocols.
    """
    sso_url: builtins.str
    """Single sign-on endpoint URL.
    Specify the link to the IdP login page here.
    """
    case_insensitive_name_ids: builtins.bool
    """Use case insensitive Name IDs."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def cookie_max_age(self) -> google.protobuf.duration_pb2.Duration:
        """Browser cookie lifetime in seconds.
        If the cookie is still valid, the management console
        authenticates the user immediately and redirects them to the home page.
        """

    @property
    def security_settings(self) -> global___FederationSecuritySettings:
        """Federation security settings."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `` key:value `` pairs. Maximum of 64 per resource."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        organization_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        cookie_max_age: google.protobuf.duration_pb2.Duration | None = ...,
        auto_create_account_on_login: builtins.bool = ...,
        issuer: builtins.str = ...,
        sso_binding: global___BindingType.ValueType = ...,
        sso_url: builtins.str = ...,
        security_settings: global___FederationSecuritySettings | None = ...,
        case_insensitive_name_ids: builtins.bool = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cookie_max_age", b"cookie_max_age", "created_at", b"created_at", "security_settings", b"security_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auto_create_account_on_login", b"auto_create_account_on_login", "case_insensitive_name_ids", b"case_insensitive_name_ids", "cookie_max_age", b"cookie_max_age", "created_at", b"created_at", "description", b"description", "id", b"id", "issuer", b"issuer", "labels", b"labels", "name", b"name", "organization_id", b"organization_id", "security_settings", b"security_settings", "sso_binding", b"sso_binding", "sso_url", b"sso_url"]) -> None: ...

global___Federation = Federation

@typing.final
class FederationSecuritySettings(google.protobuf.message.Message):
    """Federation security settings."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENCRYPTED_ASSERTIONS_FIELD_NUMBER: builtins.int
    FORCE_AUTHN_FIELD_NUMBER: builtins.int
    encrypted_assertions: builtins.bool
    """Enable encrypted assertions."""
    force_authn: builtins.bool
    """Value parameter ForceAuthn in SAMLRequest."""
    def __init__(
        self,
        *,
        encrypted_assertions: builtins.bool = ...,
        force_authn: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["encrypted_assertions", b"encrypted_assertions", "force_authn", b"force_authn"]) -> None: ...

global___FederationSecuritySettings = FederationSecuritySettings



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datasphere/v2/resource_types.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/yandex/cloud/datasphere/v2/resource_types.proto\x12\x1ayandex.cloud.datasphere.v2*\xd5\x01\n\x0cResourceType\x12\x1d\n\x19RESOURCE_TYPE_UNSPECIFIED\x10\x00\x12\x18\n\x14RESOURCE_TYPE_SECRET\x10\x02\x12\x1e\n\x1aRESOURCE_TYPE_DOCKER_IMAGE\x10\x03\x12\x19\n\x15RESOURCE_TYPE_DATASET\x10\x04\x12\x14\n\x10RESOURCE_TYPE_S3\x10\x05\x12\x16\n\x12RESOURCE_TYPE_NODE\x10\x06\x12\x17\n\x13RESOURCE_TYPE_ALIAS\x10\x08\"\x04\x08\x01\x10\x01\"\x04\x08\x07\x10\x07\x42|\n\x1eyandex.cloud.api.datasphere.v2B\x0f\x44sResourceTypesZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v2;datasphereb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datasphere.v2.resource_types_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036yandex.cloud.api.datasphere.v2B\017DsResourceTypesZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v2;datasphere'
  _globals['_RESOURCETYPE']._serialized_start=80
  _globals['_RESOURCETYPE']._serialized_end=293
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.mdb.mysql.v1.user_pb2
import yandex.cloud.mdb.mysql.v1.user_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class UserServiceStub:
    """A set of methods for managing MySQL users.

    See [the documentation](/docs/managed-mysql/operations/cluster-users) for details.
    """

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.mysql.v1.user_service_pb2.GetUserRequest,
        yandex.cloud.mdb.mysql.v1.user_pb2.User,
    ]
    """Retrieves information about the specified user."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.mysql.v1.user_service_pb2.ListUsersRequest,
        yandex.cloud.mdb.mysql.v1.user_service_pb2.ListUsersResponse,
    ]
    """Retrieves the list of users in a cluster."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.mysql.v1.user_service_pb2.CreateUserRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a user in a cluster."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.mysql.v1.user_service_pb2.UpdateUserRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates a user in a cluster."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.mysql.v1.user_service_pb2.DeleteUserRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes a user in a cluster."""

    GrantPermission: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.mysql.v1.user_service_pb2.GrantUserPermissionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Grants permission to access a database to a user in a cluster."""

    RevokePermission: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.mysql.v1.user_service_pb2.RevokeUserPermissionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Revokes permission to access a database from a user in a cluster."""

class UserServiceAsyncStub:
    """A set of methods for managing MySQL users.

    See [the documentation](/docs/managed-mysql/operations/cluster-users) for details.
    """

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.mysql.v1.user_service_pb2.GetUserRequest,
        yandex.cloud.mdb.mysql.v1.user_pb2.User,
    ]
    """Retrieves information about the specified user."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.mysql.v1.user_service_pb2.ListUsersRequest,
        yandex.cloud.mdb.mysql.v1.user_service_pb2.ListUsersResponse,
    ]
    """Retrieves the list of users in a cluster."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.mysql.v1.user_service_pb2.CreateUserRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a user in a cluster."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.mysql.v1.user_service_pb2.UpdateUserRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates a user in a cluster."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.mysql.v1.user_service_pb2.DeleteUserRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes a user in a cluster."""

    GrantPermission: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.mysql.v1.user_service_pb2.GrantUserPermissionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Grants permission to access a database to a user in a cluster."""

    RevokePermission: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.mysql.v1.user_service_pb2.RevokeUserPermissionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Revokes permission to access a database from a user in a cluster."""

class UserServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing MySQL users.

    See [the documentation](/docs/managed-mysql/operations/cluster-users) for details.
    """

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.mdb.mysql.v1.user_service_pb2.GetUserRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.mysql.v1.user_pb2.User, collections.abc.Awaitable[yandex.cloud.mdb.mysql.v1.user_pb2.User]]:
        """Retrieves information about the specified user."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.mdb.mysql.v1.user_service_pb2.ListUsersRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.mysql.v1.user_service_pb2.ListUsersResponse, collections.abc.Awaitable[yandex.cloud.mdb.mysql.v1.user_service_pb2.ListUsersResponse]]:
        """Retrieves the list of users in a cluster."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.mdb.mysql.v1.user_service_pb2.CreateUserRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a user in a cluster."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.mdb.mysql.v1.user_service_pb2.UpdateUserRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates a user in a cluster."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.mdb.mysql.v1.user_service_pb2.DeleteUserRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes a user in a cluster."""

    @abc.abstractmethod
    def GrantPermission(
        self,
        request: yandex.cloud.mdb.mysql.v1.user_service_pb2.GrantUserPermissionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Grants permission to access a database to a user in a cluster."""

    @abc.abstractmethod
    def RevokePermission(
        self,
        request: yandex.cloud.mdb.mysql.v1.user_service_pb2.RevokeUserPermissionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Revokes permission to access a database from a user in a cluster."""

def add_UserServiceServicer_to_server(servicer: UserServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.cloudregistry.v1 import registry_pb2 as yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__pb2
from yandex.cloud.cloudregistry.v1 import registry_service_pb2 as yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class RegistryServiceStub(object):
    """A set of methods for managing Registry resources.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.cloudregistry.v1.RegistryService/Get',
                request_serializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.GetRegistryRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__pb2.Registry.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.cloudregistry.v1.RegistryService/List',
                request_serializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListRegistriesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListRegistriesResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/yandex.cloud.cloudregistry.v1.RegistryService/Create',
                request_serializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.CreateRegistryRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/yandex.cloud.cloudregistry.v1.RegistryService/Update',
                request_serializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.UpdateRegistryRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/yandex.cloud.cloudregistry.v1.RegistryService/Delete',
                request_serializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.DeleteRegistryRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListAccessBindings = channel.unary_unary(
                '/yandex.cloud.cloudregistry.v1.RegistryService/ListAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
                )
        self.SetAccessBindings = channel.unary_unary(
                '/yandex.cloud.cloudregistry.v1.RegistryService/SetAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.UpdateAccessBindings = channel.unary_unary(
                '/yandex.cloud.cloudregistry.v1.RegistryService/UpdateAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListIpPermissions = channel.unary_unary(
                '/yandex.cloud.cloudregistry.v1.RegistryService/ListIpPermissions',
                request_serializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListIpPermissionsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListIpPermissionsResponse.FromString,
                )
        self.SetIpPermissions = channel.unary_unary(
                '/yandex.cloud.cloudregistry.v1.RegistryService/SetIpPermissions',
                request_serializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.SetIpPermissionsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.UpdateIpPermissions = channel.unary_unary(
                '/yandex.cloud.cloudregistry.v1.RegistryService/UpdateIpPermissions',
                request_serializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.UpdateIpPermissionsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListArtifacts = channel.unary_unary(
                '/yandex.cloud.cloudregistry.v1.RegistryService/ListArtifacts',
                request_serializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListArtifactsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListArtifactsResponse.FromString,
                )


class RegistryServiceServicer(object):
    """A set of methods for managing Registry resources.
    """

    def Get(self, request, context):
        """Returns the specified Registry resource.

        To get the list of available Registry resources, make a [RegistryService.List] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves the list of Registry resources in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates a registry in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates the specified registry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes the specified registry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAccessBindings(self, request, context):
        """access

        Lists access bindings for the specified registry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAccessBindings(self, request, context):
        """Sets access bindings for the specified registry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAccessBindings(self, request, context):
        """Updates access bindings for the specified registry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListIpPermissions(self, request, context):
        """List ip permissions for the specified registry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetIpPermissions(self, request, context):
        """Set ip permissions for the specified registry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateIpPermissions(self, request, context):
        """Update ip permissions for the specified registry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListArtifacts(self, request, context):
        """Retrieves the list of registry artifact resources in the specified registry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RegistryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.GetRegistryRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__pb2.Registry.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListRegistriesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListRegistriesResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.CreateRegistryRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.UpdateRegistryRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.DeleteRegistryRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.SerializeToString,
            ),
            'SetAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdateAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListIpPermissions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListIpPermissions,
                    request_deserializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListIpPermissionsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListIpPermissionsResponse.SerializeToString,
            ),
            'SetIpPermissions': grpc.unary_unary_rpc_method_handler(
                    servicer.SetIpPermissions,
                    request_deserializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.SetIpPermissionsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdateIpPermissions': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateIpPermissions,
                    request_deserializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.UpdateIpPermissionsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListArtifacts': grpc.unary_unary_rpc_method_handler(
                    servicer.ListArtifacts,
                    request_deserializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListArtifactsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListArtifactsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.cloudregistry.v1.RegistryService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RegistryService(object):
    """A set of methods for managing Registry resources.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cloudregistry.v1.RegistryService/Get',
            yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.GetRegistryRequest.SerializeToString,
            yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__pb2.Registry.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cloudregistry.v1.RegistryService/List',
            yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListRegistriesRequest.SerializeToString,
            yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListRegistriesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cloudregistry.v1.RegistryService/Create',
            yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.CreateRegistryRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cloudregistry.v1.RegistryService/Update',
            yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.UpdateRegistryRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cloudregistry.v1.RegistryService/Delete',
            yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.DeleteRegistryRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cloudregistry.v1.RegistryService/ListAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cloudregistry.v1.RegistryService/SetAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cloudregistry.v1.RegistryService/UpdateAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListIpPermissions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cloudregistry.v1.RegistryService/ListIpPermissions',
            yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListIpPermissionsRequest.SerializeToString,
            yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListIpPermissionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetIpPermissions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cloudregistry.v1.RegistryService/SetIpPermissions',
            yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.SetIpPermissionsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateIpPermissions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cloudregistry.v1.RegistryService/UpdateIpPermissions',
            yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.UpdateIpPermissionsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListArtifacts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cloudregistry.v1.RegistryService/ListArtifacts',
            yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListArtifactsRequest.SerializeToString,
            yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__service__pb2.ListArtifactsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
